@@ -5,13 +5,13 @@ _geomesa-cassandra(){
   prev="${COMP_WORDS[COMP_CWORD-1]}";
 
   if [[ "${COMP_WORDS[1]}" == "help" ]]; then
-    COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain configure classpath scala-console" ${cur}));
+    COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain update-schema configure classpath scala-console" ${cur}));
     return 0;
   fi;
 
   case ${COMP_CWORD} in
     1)
-      COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain configure classpath scala-console" ${cur}));
+      COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain update-schema configure classpath scala-console" ${cur}));
       ;;
     [2-9] | [1-9][0-9])
       if [[ "${cur}" =~ ^-[a-zA-Z-]?+$ ]]; then
@@ -53,20 +53,24 @@ _geomesa-cassandra(){
               return 0;
               ;;
                   ingest)
-              COMPREPLY=( $(compgen -W "--run-mode --catalog --threads --no-tracking --force --src-list --converter-error-mode --feature-name --contact-point --user --password --converter --split-max-size --input-format --key-space --spec" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--catalog --threads --no-tracking --force --src-list --combine-inputs --input-format --converter-error-mode --feature-name --contact-point --user --password --converter --run-mode --split-max-size --key-space --spec" -- ${cur}));
               return 0;
               ;;
                   export)
-              COMPREPLY=( $(compgen -W "--contact-point --feature-name --hints --key-space --index --output-format --cql --catalog --output --no-header --max-features --gzip --attributes --user --password" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--contact-point --attribute --chunk-size --feature-name --force --hints --key-space --index --sort-by --num-reducers --cql --catalog --output-format --output --no-header --max-features --run-mode --gzip --attributes --user --password --sort-descending" -- ${cur}));
               return 0;
               ;;
                   playback)
-              COMPREPLY=( $(compgen -W "--user --attributes --password --interval --no-header --catalog --output --max-features --gzip --step-window --dtg --key-space --cql --hints --output-format --contact-point --rate --feature-name" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--user --attributes --sort-descending --run-mode --output --output-format --dtg --key-space --cql --hints --chunk-size --rate --num-reducers --password --interval --no-header --attribute --catalog --max-features --gzip --step-window --sort-by --force --contact-point --feature-name" -- ${cur}));
               return 0;
               ;;
                   explain)
               COMPREPLY=( $(compgen -W "--hints --key-space --user --contact-point --cql --feature-name --index --attributes --password --catalog" -- ${cur}));
               return 0;
+              ;;
+                  update-schema)
+              COMPREPLY=( $(compgen -W "--rename --add-keyword --key-space --password --rename-attribute --rename-tables --add-attribute --user --feature-name --catalog --force --remove-keyword --enable-stats --no-backup --contact-point" -- ${cur}));
+              return 0;
               ;;
                   configure)
               COMPREPLY=( $(compgen -W "" -- ${cur}));
